@@ -2,6 +2,9 @@ import sys
 import os
 import signal
 
+from ptlibs.dns_cache_hosts import install_dns_cache
+install_dns_cache()
+
 from ptlibs.ptprinthelper import ptprint, out_if
 
 def signal_handler(sig, frame):
@@ -12,4 +15,6 @@ def signal_handler(sig, frame):
     os._exit(1)
 
 # Register the signal handler for SIGINT
-signal.signal(signal.SIGINT, signal_handler)
\ No newline at end of file
+signal.signal(signal.SIGINT, signal_handler)
+
+
